@@ -29,6 +29,7 @@
 #include "gnome-vfs-cancellable-ops.h"
 #include "gnome-vfs-method.h"
 #include "gnome-vfs-private-utils.h"
+#include "gnome-vfs-utils.h"
 #include "gnome-vfs-handle-private.h"
 
 #include <glib/gmessages.h>
@@ -296,8 +297,26 @@ gnome_vfs_find_directory_cancellable (GnomeVFSURI *near_uri,
 	if (near_uri != NULL) {
 		gnome_vfs_uri_ref (near_uri);
 	} else {
+		char *text_uri;
+
+		text_uri = gnome_vfs_get_uri_from_local_path (g_get_home_dir ());
+		g_assert (text_uri != NULL);
 		/* assume file: method and the home directory */
-		near_uri = gnome_vfs_uri_new (g_get_home_dir());
+		near_uri = gnome_vfs_uri_new (text_uri);
+		g_free (text_uri);
+	}
+
+	g_assert (near_uri != NULL);
+
+	if (!VFS_METHOD_HAS_FUNC (near_uri->method, find_directory)) {
+		/* skip file systems not supporting find_directory.
+		 *
+		 * TODO if we decide to introduce cross-method links (e.g. http allows
+		 * arbitrary URIs), this could be slightly wrong, because the target
+		 * method may support find_directory, so we'd also have to make sure
+		 * that a method doesn't support cross-method links.
+		 **/
+		return GNOME_VFS_ERROR_NOT_SUPPORTED;
 	}
 
 	/* Need to expand the final symlink, since if the directory is a symlink
