@@ -972,9 +972,8 @@ do_read (GnomeVFSMethod *method,
 	}
 
 	dbus_message_iter_recurse (&iter, &array_iter);
-	if (dbus_message_iter_get_array_len (&array_iter) > 0) {
-		dbus_message_iter_get_fixed_array (&array_iter, &data, &size);
-		
+	dbus_message_iter_get_fixed_array (&array_iter, &data, &size);
+	if (size > 0) {
 		memcpy (buffer, data, size);
 	} 
 
@@ -1780,6 +1779,10 @@ do_monitor_add (GnomeVFSMethod        *method,
 							   -1, NULL);
 
 	dbus_message_unref (message);
+
+	if (reply == NULL) {
+		return GNOME_VFS_ERROR_INTERNAL;
+	}
 	
 	if (check_if_reply_is_error (reply, &result)) {
 		return result;
@@ -1838,6 +1841,10 @@ do_monitor_cancel (GnomeVFSMethod       *method,
 
 	dbus_message_unref (message);
 
+	if (reply == NULL) {
+		return GNOME_VFS_ERROR_INTERNAL;
+	}
+	
 	if (check_if_reply_is_error (reply, &result)) {
 		return result;
 	}
